Exception: Coat::Error
- Inherits:
-
StandardError
- Object
- StandardError
- Coat::Error
- Defined in:
- lib/coat.rb
Overview
Every failure the CLI knows how to report as a single line.
Every failure the CLI knows how to report as a single line.