Module: Coat::Sayings

Defined in:
lib/coat/sayings.rb

Overview

A line from Dolly at the top of every coat. Short on purpose - a page of someone else's build logs is no place for a wall of epigraph, and lyrics are quoted a line at a time.

Defined Under Namespace

Classes: Saying

Constant Summary collapse

ALL =
[
  Saying.new(text: "Find out who you are and do it on purpose."),
  Saying.new(text: "If you don't like the road you're walking, start paving another one."),
  Saying.new(text: "Storms make trees take deeper roots."),
  Saying.new(text: "The way I see it, if you want the rainbow, you gotta put up with the rain."),
  Saying.new(text: "Don't get so busy making a living that you forget to make a life."),
  Saying.new(text: "You'll never do a whole lot unless you're brave enough to try."),
  Saying.new(text: "I'm not going to limit myself just because people won't accept the " \
                  "fact that I can do something else."),
  Saying.new(text: "We had no money, but I was rich as I could be.",
             source: "Coat of Many Colors"),
  Saying.new(text: "One is only poor only if they choose to be.",
             source: "Coat of Many Colors")
].freeze

Class Method Summary collapse

Class Method Details

.randomObject



25
26
27
# File 'lib/coat/sayings.rb', line 25

def self.random
  ALL.sample
end